"""gustaf/gustaf/utils/tictoc.py.

Timer that tics, tocs and logs.
"""
